﻿using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.alipay
{
    /// <summary>
    /// Alipay決済 決済要求サンプル
    /// </summary>
    public partial class CLI_AlipayAuthorize
    {
        public virtual void Exec()
        {
            /**
             * 取引ID
             */
            String orderId = "dummy" + System.DateTime.Now.ToString("HHmmssfff");

            /**
             * 金額
             * 
             * 通貨がCNYの場合は、100以上の値の指定が必須
             */
            String amount = "10";

            /**
             * 通貨
             * 
             * "JPY"：日本円、"CNY"：中国元
             */
            String currency = "JPY";

            /**
             * 決済種別
             * 
             * "0"：オンライン決済、"1"：バーコード決済(店舗スキャン型)、"2"：バーコード決済(消費者スキャン型)
             */
            String payType = "0";

            /**
             * ユーザ識別コード
             * 決済種別がバーコード決済(店舗スキャン型)の場合は指定必須
             * 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定不可
             */
            String identityCode = "1234567890";

            /**
             * 商品名
             */
            String commodityName = "新製品";

            /**
             * 商品詳細
             * 
             * 決済種別がオンライン決済、バーコード決済(消費者スキャン型)の場合は指定任意
             * 決済種別がバーコード決済(店舗スキャン型)の場合は指定不可
             */
            String commodityDescription = "新製品詳細";

            /**
             * 商品ID
             * 
             * 決済種別がバーコード決済(消費者スキャン型)、かつ、商品詳細を指定する場合は指定必須
             * 決済種別がオンライン決済、バーコード決済(店舗スキャン型)の場合は指定不可
             */
            String commodityId = "newItemId";

            /**
             * 決済成功時URL
             * 
             * 決済種別がオンライン決済の場合は指定必須
             * 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
             */
            String successUrl = "http://127.0.0.1:59857/alipay/AuthorizeResult.aspx";

            /**
             * 決済エラー時URL
             * 
             * 決済種別がオンライン決済の場合は指定必須
             * 決済種別がバーコード決済(店舗スキャン型)、バーコード決済(消費者スキャン型)の場合は指定不可
             */
            String errorUrl = "http://127.0.0.1:59857/alipay/AuthorizeResult.aspx";

            /**
             * 要求電文パラメータ値の指定
             */
            AlipayAuthorizeRequestDto requestData = new AlipayAuthorizeRequestDto();
            requestData.OrderId = orderId;
            requestData.Amount = amount;
            requestData.Currency = currency;
            requestData.PayType = payType;
            requestData.CommodityName = commodityName;
            if ("0".Equals(requestData.PayType))
            {
                requestData.CommodityDescription = commodityDescription;
                requestData.SuccessUrl = successUrl;
                requestData.ErrorUrl = errorUrl;
            }
            else if ("1".Equals(requestData.PayType))
            {
                requestData.IdentityCode = identityCode;
            }
            else if ("2".Equals(requestData.PayType))
            {
                requestData.CommodityDescription = commodityDescription;
                requestData.CommodityId = commodityId;
            }

            /**
             * 実行と結果表示
             */
            Transaction tran = new Transaction();
            AlipayAuthorizeResponseDto responseData = (AlipayAuthorizeResponseDto)tran.Execute(requestData);

            System.Console.WriteLine("<< REQUEST >>");
            System.Console.WriteLine("Order ID:" + requestData.OrderId);
            System.Console.WriteLine("Amount:" + requestData.Amount);
            System.Console.WriteLine("Currency:" + requestData.Currency);
            System.Console.WriteLine("Pay Type:" + requestData.PayType);

            System.Console.WriteLine("<< RESPONSE >>");
            System.Console.WriteLine("MStatus:" + responseData.Mstatus);
            System.Console.WriteLine("Message:" + responseData.MerrMsg);
            System.Console.WriteLine("Result Code:" + responseData.VResultCode);
            if ("1".Equals(requestData.PayType) || "2".Equals(requestData.PayType))
            {
                System.Console.WriteLine("Cust Txn:" + responseData.CustTxn);
                System.Console.WriteLine("Center Trade ID:" + responseData.CenterTradeId);
            }
            if ("1".Equals(requestData.PayType))
            {
                System.Console.WriteLine("Pay Time JP:" + responseData.PayTimeJp);
                System.Console.WriteLine("Pay Time CN:" + responseData.PayTimeCn);
                System.Console.WriteLine("Buyer Charged Amount CNY:" + responseData.BuyerChargedAmountCny);
            }
            else if ("2".Equals(requestData.PayType))
            {
                System.Console.WriteLine("Qr Code:" + responseData.QrCode);
                System.Console.WriteLine("Qr Code Img Url:" + responseData.QrCodeImgUrl);
                System.Console.WriteLine("Qr Code Small Img Url:" + responseData.QrCodeSmallImgUrl);
                System.Console.WriteLine("Qr Code Large Img Url:" + responseData.QrCodeLargeImgUrl);
            }
        }
    }
}
