﻿using System;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace ConsoleApplication.em
{
    /// <summary>
    /// 電子マネー決済 申込要求サンプル
    /// </summary>
    public partial class CLI_EmAuthorize
    {
        public virtual void Exec()
        {
            /**
             * 決済方式
             * 
             * サイバー Edy     (パソリ)         : edy-pc
             * モバイル Edy                      : edy-mobile
             * モバイル Edy ダイレクト           : edy-direct
             * モバイルSuicaメール決済           : suica-mobile-mail
             * モバイルSuicaアプリ決済           : suica-mobile-app
             * Suicaインターネット決済メール連携 : suica-pc-mail
             * Suicaインターネット決済アプリ連携 : suica-pc-app
             * nanaco決済                        : tcc-redirect
             */
            String serviceOptionType = "suica-mobile-app";
            /**
             * 取引ID
             */
            String orderId = "dummy" + System.DateTime.Now.ToString("HHmmssfff");
            /**
             * 決済金額
             * 3GPSMDK.propertiesのダミーリクエストフラグ：1の場合、以下の値に限り成功となります。
             * edy:1001
             * suica:1003
             */
            String amount = "1003";
            /**
             * 決済期限
             * サイバーEdy、モバイルEdyダイレクト、nanaco決済では使用しません。
             */
            String settlementLimit = System.DateTime.Now.AddDays(5).ToString("yyyyMMddhhmmss");
            /**
             * メールアドレス
             * サイバーEdy、モバイルEdyダイレクト、Suica決済アプリ連携、nanaco決済では使用しません。
             */
            String mailAddress = "sample.sample@vt-mdk.co.jp";
            /**
             * 画面タイトル 
             * Edy、nanaco決済では利用しません。
             */
            String screenTitle = "For Suica";

            /**
             * 要求電文パラメータ値の指定
             */
            EmAuthorizeRequestDto requestData = new EmAuthorizeRequestDto();
            requestData.ServiceOptionType = serviceOptionType;
            requestData.OrderId = orderId;
            requestData.Amount = amount;
            if (serviceOptionType.Equals("edy-pc") == false &&
                serviceOptionType.Equals("edy-direct") == false &&
                serviceOptionType.Equals("tcc-redirect") == false
                )
            {
                requestData.SettlementLimit = settlementLimit;
            }
            if (serviceOptionType.Equals("edy-pc") == false &&
                serviceOptionType.Equals("edy-direct") == false &&
                serviceOptionType.Equals("suica-mobile-app") == false &&
                serviceOptionType.Equals("suica-pc-app") == false &&
                serviceOptionType.Equals("tcc-redirect") == false
                )
            {
                requestData.MailAddr = mailAddress;
            }
            if (serviceOptionType.Equals("edy-pc") == false &&
                serviceOptionType.Equals("edy-mobile") == false &&
                serviceOptionType.Equals("edy-direct") == false &&
                serviceOptionType.Equals("tcc-redirect") == false
                )
            {
                requestData.ScreenTitle = screenTitle;
            }
            if (serviceOptionType.Equals("tcc-redirect"))
            {
                requestData.UserId = "dummy" + DateTime.Now.ToString("HHmmssfff");
                requestData.TransactionKind = "02";
            }


            /**
             * 実行と結果表示
             */
            Transaction tran = new Transaction();
            EmAuthorizeResponseDto responseData = (EmAuthorizeResponseDto)tran.Execute(requestData);

            System.Console.WriteLine("<< REQUEST >>");
            System.Console.WriteLine("ServiceOptionType:" + requestData.ServiceOptionType);
            System.Console.WriteLine("Order ID:" + requestData.OrderId);
            System.Console.WriteLine("Amount:" + requestData.Amount);

            System.Console.WriteLine("<< RESPONSE >>");
            System.Console.WriteLine("MStatus:" + responseData.Mstatus);
            System.Console.WriteLine("Message:" + responseData.MerrMsg);
            System.Console.WriteLine("Result Code:" + responseData.VResultCode);
            System.Console.WriteLine("Receipt No:" + responseData.ReceiptNo);
            System.Console.WriteLine("Application URL:" + responseData.AppUrl);
        }
    }
}
