﻿using System;

namespace jp.veritrans.tercerog.sample.util
{
    using MdkServiceConstants = jp.veritrans.tercerog.mdk.dto.MdkServiceConstants;

    /// <summary>
    /// キャリア用ユーティリティクラス
    /// 
    /// @author t-hatakeyama
    /// 
    /// </summary>
    public class CarrierUtility
    {

        /// <summary>
        /// インスタンス
        /// </summary>
        public static CarrierUtility instance = new CarrierUtility();

        /// <summary>
        /// docomoのIPアドレス一覧(一部) </summary>
        private static string[] docomoIpAddressList = { "1.66.96.0/21", "1.66.104.0/23", "1.72.0.0/14", "1.76.0.0/18" };
        /// <summary>
        /// auのIPアドレス一覧(定義のみ) </summary>
        private static string[] auIpAddressList = { };

        /// <summary>
        /// コンストラクタ
        /// </summary>
        private CarrierUtility()
        {
            // propertiesファイルからIPアドレスを取得する
        }

        /// <summary>
        /// HTMLヘッダから端末種別を取得する
        /// </summary>
        /// <param name="userAgent"> HTMLヘッダのuser-agent部分 </param>
        /// <returns> "1":スマートフォン、"2":フィーチャーフォン（ガラケー） </returns>
        public virtual string getTerminalKind(string userAgent)
        {
            // 文字列比較により、端末種別を決める
            if (userAgent.IndexOf("DoCoMo") == 0 || userAgent.IndexOf("J-PHONE") == 0 || userAgent.IndexOf("Vodafone") == 0 || userAgent.IndexOf("SoftBank") == 0 || userAgent.IndexOf("UP.Browser") == 0 || userAgent.IndexOf("KDDI") == 0) // au -  softbank -  docomo
            {
                // user-agentの開始文字が上記の場合に、フィーチャフォンと判断する
                return "2";
            }
            else if (userAgent.IndexOf("iPhone") > 0 && userAgent.IndexOf("iPad") == -1 || userAgent.IndexOf("iPod") > 0 || userAgent.IndexOf("Android") > 0)
            {
                // user-agentの文字列の中に上記がある場合に、 スマートフォンと判断する
                return "1";
            }

            // それ以外（PC）
            return null;
        }

        /// <summary>
        /// エンコーディングする文字列を返す
        /// ・terminalKindがフィーチャーフォンの場合はShift_JIS固定
        /// ・キャリアが、docomo,sbpsの場合はShift_JIS固定
        /// ・上記以外はUTF-8
        /// </summary>
        /// <param name="carrier"> </param>
        /// <param name="terminalKind">
        /// @return </param>
        public static string getEncoding(string carrier, string terminalKind)
        {
            if (terminalKind.Equals(MdkServiceConstants.CARRIER_TERMINAL_FP))
            {
                return "Shift_JIS";
            }

            if (carrier.Equals(MdkServiceConstants.CARRIER_DOCOMO) || carrier.Equals(MdkServiceConstants.CARRIER_SB_KTAI))
            {
                return "Shift_JIS";
            }
            return "UTF-8";
        }
    }
}

internal static class StringHelperClass
{
    //------------------------------------------------------------------------------------
    //	This method is used to replace most calls to the Java String.split method.
    //------------------------------------------------------------------------------------
    internal static string[] StringSplit(string source, string regexDelimiter, bool trimTrailingEmptyStrings)
    {
        string[] splitArray = System.Text.RegularExpressions.Regex.Split(source, regexDelimiter);

        if (trimTrailingEmptyStrings)
        {
            if (splitArray.Length > 1)
            {
                for (int i = splitArray.Length; i > 0; i--)
                {
                    if (splitArray[i - 1].Length > 0)
                    {
                        if (i < splitArray.Length)
                            System.Array.Resize(ref splitArray, i);

                        break;
                    }
                }
            }
        }

        return splitArray;
    }
}