﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MdkSampleDotNet;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.linepay
{
    public partial class Authorize : System.Web.UI.Page
    {
        /// <summary>
        /// 初期表示イベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                orderId.Text = "dummy" + Utils.CurrentTimeMillis();
                amount.Text = Request.QueryString["price"];
                itemName.Text = Request.QueryString["item_name"];

                string successUrlStr = Request["successUrl"];
                if (successUrlStr == null)
                {
                    successUrlStr = MdkSampleDotNet.Utils.getXPath(MdkSampleDotNet.SampleConstants.LINEPAY_SUCCESS_URL);
                }
                successUrl.Text = successUrlStr;
                hidSuccessUrl.Value = successUrlStr;

                string cancelUrlStr = Request["cancelUrl"];
                if (cancelUrlStr == null)
                {
                    cancelUrlStr = MdkSampleDotNet.Utils.getXPath(MdkSampleDotNet.SampleConstants.LINEPAY_CANCEL_URL);
                }
                cancelUrl.Text = cancelUrlStr;
                hidCancelUrl.Value = cancelUrlStr;

                string errorUrlStr = Request["errorUrl"];
                if (errorUrlStr == null)
                {
                    errorUrlStr = MdkSampleDotNet.Utils.getXPath(MdkSampleDotNet.SampleConstants.LINEPAY_ERROR_URL);
                }
                errorUrl.Text = errorUrlStr;
                hidErrorUrl.Value = errorUrlStr;

                string pushUrlStr = Request["pushUrl"];
                if (pushUrlStr == null)
                {
                    pushUrlStr = MdkSampleDotNet.Utils.getXPath(MdkSampleDotNet.SampleConstants.LINEPAY_PUSH_URL);
                }

                String dummyRequest = MerchantContext.Config.GetValue(MerchantConfig.DUMMY_REQUEST);
                if ("1".Equals(dummyRequest))
                {
                    pushUrl.ReadOnly = false;
                    pushUrl.Text = pushUrlStr;
                }
                else
                {
                    pushUrl.ReadOnly = true;
                    pushUrl.Text = "";
                }

                amount.Text = Request["amount"] + Request["price"];

                withCapture.Items.Add(new ListItem("与信のみ(与信成功後に売上処理を行う必要があります)", MdkServiceConstants.LINEPAY_AUTH_ONLY));
                withCapture.Items.Add(new ListItem("与信売上(与信と同時に売上処理も行います)", MdkServiceConstants.LINEPAY_AUTH_WITH_CAPTURE));

                checkUseBrowser.Items.Add(new ListItem("LINE Pay側でブラウザ判定しない", MdkServiceConstants.LINEPAY_NOT_CHECK_USE_BROWSER));
                checkUseBrowser.Items.Add(new ListItem("LINE Pay側でブラウザ判定する", MdkServiceConstants.LINEPAY_CHECK_USE_BROWSER));

                useOriginalApp.Items.Add(new ListItem("オプションを使用しない", MdkServiceConstants.LINEPAY_NOT_USE_ORIGINAL_APP));
                useOriginalApp.Items.Add(new ListItem("URLエンコーディングを使用する", MdkServiceConstants.LINEPAY_USE_ORIGINAL_APP_ENCODING));

                paymentConfirmType.Items.Add(new ListItem("ブラウザを介する通信", MdkServiceConstants.LINEPAY_TRIPARTITE_COMMUNICATION));
                paymentConfirmType.Items.Add(new ListItem("サーバ間通信", MdkServiceConstants.LINEPAY_TWO_PARTIES_COMMUNICATION));

                itemId.Text = Request["itemId"];
            }
        }

        /// <summary>
        /// 取引ID更新ボタンイベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnReplaceOrderId_Click(object sender, EventArgs e)
        {
            // HiddenField更新
            hidSuccessUrl.Value = successUrl.Text;
            hidCancelUrl.Value = cancelUrl.Text;
            hidErrorUrl.Value = errorUrl.Text;

            orderId.Text = "dummy" + Utils.CurrentTimeMillis();
        }

        /// <summary>
        /// 購入ボタンイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnSubmit_Click(object sender, EventArgs e)
        {
            // HiddenField更新
            hidSuccessUrl.Value = successUrl.Text;
            hidCancelUrl.Value = cancelUrl.Text;
            hidErrorUrl.Value = errorUrl.Text;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 取引IDの取得
            String paramOrderId = orderId.Text;
            // 金額の取得
            String paramAmount = amount.Text;
            // 与信同時売上フラグの取得
            String paramWithCapture = withCapture.SelectedValue;
            // 商品名の取得
            String paramItemName = itemName.Text;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            if (String.IsNullOrEmpty(paramOrderId))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>";
                return;
            }

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 画面入力値を実行クラスに渡すためにセッションに設定します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Session["paramOrderId"] = paramOrderId;
            Session["paramAmount"] = paramAmount;
            Session["paramWithCapture"] = paramWithCapture;
            Session["paramItemId"] = itemId.Text;
            Session["paramItemName"] = paramItemName;
            Session["paramItemImageUrl"] = itemImageUrl.Text;
            Session["paramCheckUseBrowser"] = checkUseBrowser.SelectedValue;
            Session["paramAppUrlScheme"] = appUrlScheme.Text;
            Session["paramUseOriginalApp"] = useOriginalApp.SelectedValue;
            Session["paramPackageName"] = packageName.Text;
            Session["paramSuccessUrl"] = successUrl.Text;
            Session["paramCancelUrl"] = cancelUrl.Text;
            Session["paramErrorUrl"] = errorUrl.Text;
            Session["paramPaymentConfirmType"] = paymentConfirmType.SelectedValue;
            Session["paramOneTimeKey"] = oneTimeKey.Text;
            Session["paramPushUrl"] = pushUrl.Text;
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 実行＆結果画面を表示します
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            Response.Redirect("./AuthorizeExec.aspx", true);
        }

    }
}
