﻿using System;
using System.Web.UI;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.paynowid
{
    public partial class CardAuthorizeExec1 : Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            // 取引ID
            var orderId = (Session["orderId"] != null) ? Session["orderId"].ToString() : null;
            // 金額
            var amount = (Session["amount"] != null) ? Session["amount"].ToString() : null;
            //与信方法
            var withCapture = (Session["withCapture"] != null) ? Session["withCapture"].ToString() : "";
            // カードID
            var cardId = (Session["cardSelect"] != null) ? Session["cardSelect"].ToString() : null;
            // 支払方法
            var jpo1 = (Session["jpo1"] != null) ? Session["jpo1"].ToString() : null;
            // 支払い回数
            var jpo2 = (Session["jpo2"] != null) ? Session["jpo2"].ToString() : null;
            // セキュリティコード
            var securityCode = (Session["secureCd"] != null) ? Session["secureCd"].ToString() : null;
            // カード番号
            var cardNumber = (Session["cardNumber"] != null) ? Session["cardNumber"].ToString() : null;
            // 有効期限
            var cardExpire = (Session["cardExpire"] != null) ? Session["cardExpire"].ToString() : null;
            // 会員ID
            var accountId = (Session["accountId"] != null) ? Session["accountId"].ToString() : null;

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            if (string.IsNullOrEmpty(orderId))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
                return;
            }
            if (string.IsNullOrEmpty(amount))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
                return;
            }

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new CardAuthorizeRequestDto
                {
                    OrderId = orderId, // オーダーIDの設定
                    Amount = amount, // 金額の設定
                    AccountId = accountId //会員ID
                };
            if (!String.IsNullOrEmpty(cardId)) reqDto.CardId = cardId;
            if (!String.IsNullOrEmpty(cardNumber)) reqDto.CardNumber = cardNumber;
            if (!String.IsNullOrEmpty(cardExpire)) reqDto.CardExpire = cardExpire;
            
            // ペイメントオプション(支払方法・回数)の設定
            String jpo = null;
            if ("10" == jpo1 || "80" == jpo1)
            {
                jpo = jpo1;
            }
            else if ("61" == jpo1 && jpo2 != null)
            {
                jpo = jpo1 + "C" + jpo2;
            }
            if (jpo != null) reqDto.Jpo = jpo;
            // セキュリティコード設定
            if (!string.IsNullOrEmpty(securityCode)) reqDto.SecurityCode = securityCode;
            // 与信方法によって、売上フラグを設定
            if ("1" == withCapture) reqDto.WithCapture = "true";

            /* ******************************************* */
            /* 標準カードフラグを設定する場合に設定(未設定時は1)   */
            /* ******************************************* */
            // reqDto.DefaultCard = "1";

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (CardAuthorizeResponseDto)tran.Execute(reqDto);

            if (resDto.PayNowIdResponse != null)
            {
                PayNowIdStatus.Text = resDto.PayNowIdResponse.Status;
            }
            OrderId.Text = resDto.OrderId;
            MStatus.Text = resDto.Mstatus;
            VResultCode.Text = resDto.VResultCode;
            MErrMsg.Text = resDto.MerrMsg;
        }
    }
}
