﻿using System;
using System.Web.UI.WebControls;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.paynowid
{
    public partial class CardAuthorizeSelect : System.Web.UI.Page
    {
        private CardInfo[] _cardInfos;

        protected void Page_Load(object sender, EventArgs e)
        {
            if (!IsPostBack)
            {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // パラメータを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 会員ID
                String accountId = (Session["accountId"] != null) ? Session["accountId"].ToString() : null;
                // 取引ID
                String orderId = (Session["orderId"] != null) ? Session["orderId"].ToString() : null;
                // 金額
                String amount = (Session["amount"] != null) ? Session["amount"].ToString() : null;

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 入力をチェックします。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                String warning = null;
                if (string.IsNullOrEmpty(orderId))
                {
                    warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
                }
                else if (String.IsNullOrEmpty(amount))
                {
                    warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
                }
                else if (String.IsNullOrEmpty(accountId))
                {
                    warning = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                }

                // エラー時の処理
                if (!String.IsNullOrEmpty(warning))
                {
                    Session["warning"] = warning;
                    Response.Redirect("./CardAuthorize.aspx", true);
                }

                // Dtoの生成
                var reqDto = new CardInfoGetRequestDto {AccountId = accountId};

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                var tran = new Transaction();
                var resDto = (CardInfoGetResponseDto) tran.Execute(reqDto);

                // 処理結果を取得する
                String mStatus = resDto.Mstatus;

                if ("success" == mStatus)
                {
                    // カード情報
                    _cardInfos = resDto.PayNowIdResponse.Account.CardInfo;
                    Session["cardInfos"] = _cardInfos;
                    CardIdList.DataSource = _cardInfos;
                    CardIdList.DataBind();
                }
                else
                {
                    Session["warning"] = "<font color='#ff0000'><b>カード情報の取得に失敗："
                                         + resDto.MerrMsg + "</b></font>";
                    Response.Redirect("./CardAuthorize.aspx", true);
                }
            }

        }

        // カードを選択した場合
        protected void SelectCard(object sender, CommandEventArgs e)
        {
            String cardSelect = e.CommandArgument.ToString();
            _cardInfos = (CardInfo[]) Session["cardInfos"];
            foreach (var cardInfo in _cardInfos)
            {
                if (cardInfo.CardId == cardSelect)
                {
                    Session["selectedCardInfo"] = cardInfo;
                    break;
                }
            }
            Session["cardSelect"] = cardSelect;
            Response.Redirect("./CardAuthorizeInput.aspx", true);
        }

        // 別のカードを入力する場合
        protected void OtherCard(object sender, EventArgs e)
        {
            Session.Remove("cardSelect");
            Session.Remove("selectedCardInfo");
            Response.Redirect("./CardAuthorizeInput.aspx", true);
        }
    }
}
