﻿using System;
using System.Collections.Generic;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;
using MdkSampleDotNet;

namespace web.paynowid
{
    public partial class CardManage : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            ErrorMessage.Text = null;

            if (!IsPostBack)
            {
                CardDelete.Visible = false;

                // 初期値
                var dataSource = new Dictionary<String, String> {{"", "新しいカードを登録する"}};
                CardSelect.DataValueField = "Key";
                CardSelect.DataTextField = "Value";
                CardSelect.DataSource = dataSource;
                CardSelect.DataBind();
            }
            TokenApiKey.Text = Utils.getXPath(SampleConstants.TOKEN_API_KEY);
            TokenApiUrl.Text = Utils.getXPath(SampleConstants.TOKEN_API_URL);
            if (String.IsNullOrEmpty(TokenApiUrl.Text))
            {
                var uri = new Uri(MerchantContext.Config.GetValue(MerchantConfig.SERVER_URL));
                TokenApiUrl.Text = uri.ToString().TrimEnd('/') + "/4gtoken";
            }
        }

        protected void GetCardInfo_Click(object sender, EventArgs e)
        {
            // カード情報取得　//

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (String.IsNullOrEmpty(AccountId.Text)) {
                ErrorMessage.Text =  "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new CardInfoGetRequestDto {AccountId = AccountId.Text};

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (CardInfoGetResponseDto)tran.Execute(reqDto);


            if (resDto.Mstatus != "success")
            {
                ErrorMessage.Text = string.Format("<font color='#ff0000'><b>{0}</b></font>", resDto.MerrMsg);
                CardSelect.DataSource = new Dictionary<String, String> { { "", "新しいカードを登録する" } };
                CardSelect.DataBind();
                CardDelete.Visible = false;
                return;
            }

            // カード情報分繰り返す
            var dataSource = new Dictionary<String, String> { { "", "新しいカードを登録する" } };
            var cardInfos = resDto.PayNowIdResponse.Account.CardInfo;
            foreach (var cardInfo in cardInfos)
            {
                dataSource.Add(cardInfo.CardId, String.Format("{0}：{1}", cardInfo.CardNumber, cardInfo.CardExpire));
            }
            CardSelect.DataValueField = "Key";
            CardSelect.DataTextField = "Value";
            CardSelect.DataSource = dataSource;
            CardSelect.DataBind();

            CardDelete.Visible = (cardInfos.Length > 0);
        }

        protected void DeleteCardInfo_Click(object sender, EventArgs e)
        {

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 会員ID
            if (String.IsNullOrEmpty(AccountId.Text))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                return;
            }
            // カード選択
            if (String.IsNullOrEmpty(CardSelect.SelectedValue))
            {
                ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：削除対象カードを選択してください</b></font>";
                return;
            }

            Session["execMode"] = "2";
            SetCardInfoToSession();

            Response.Redirect("./CardManageExec.aspx", true);

        }

        protected void AddOrUpdateCardInfo_Click(object sender, EventArgs e)
        {

            // 入力をチェックします
            if (String.IsNullOrEmpty(CardSelect.SelectedValue))
            {
                // 会員ID
                if (String.IsNullOrEmpty(AccountId.Text))
                {
                    ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                    return;
                }
                Session["execMode"] = "3";
            }
            else
            {
                // 会員ID
                if (String.IsNullOrEmpty(AccountId.Text))
                {
                    ErrorMessage.Text = "<font color='#ff0000'><b>必須項目：会員IDが指定されていません</b></font>";
                    return;
                }
                Session["execMode"] = "";
            }


            SetCardInfoToSession();
            Response.Redirect("./CardManageExec.aspx", true);
        }


        private void SetCardInfoToSession()
        {
            Session["accountId"] = AccountId.Text;
            Session["cardSelect"] = CardSelect.SelectedValue;
            Session["paramToken"] = Token.Value;
        }


    }
}
