﻿using System;
using System.Web;
using MdkSampleDotNet;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.paynowid
{
    public partial class MpiAuthorizeExec : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 設定ファイルより取得する。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // SampleData.xmlから必要なプロパティを取得
            String termUrl = Utils.getXPath(SampleConstants.PAYNOWID_TERM_URL);

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++

            var withCapture = (Session["withCapture"] != null ? Session["withCapture"].ToString() : "");
            // 取引IDの取得
            var orderId = (Session["orderId"] != null ? Session["orderId"].ToString() : null);
            // 金額の取得
            var amount = (Session["amount"] != null ? Session["amount"].ToString() : null);
            // カード番号の取得
            var cardNumber = (Session["cardNumber"] != null ? Session["cardNumber"].ToString() : null);
            // カード有効期限の取得
            var cardExpire = (Session["cardExpire"] != null ? Session["cardExpire"].ToString() : null);
            // 支払方法の取得
            var jpo1 = (Session["jpo1"] != null ? Session["jpo1"].ToString() : null);
            // 支払回数の取得
            var jpo2 = (Session["jpo2"] != null ? Session["jpo2"].ToString() : null);
            // セキュリティコードの取得
            var securityCode = (Session["secureCd"] != null ? Session["secureCd"].ToString() : null);
            // 会員IDの取得
            var accountId = (Session["accountId"] != null ? Session["accountId"].ToString() : null);
            // カードIDの取得
            var cardId = (Session["cardSelect"] != null ? Session["cardSelect"].ToString() : null);
            // 決済種別
            var paymentMode = (Session["paymentMode"] != null ? Session["paymentMode"].ToString() : "");
            // HTTP-Acceptの取得

            // 会員登録がされていなかった場合
            if (Session["payNowIdStatus"] != null && Session["payNowIdStatus"].ToString() == SampleConstants.TXN_FAILURE_CODE)
            {
                var mStatus = (Session["mStatus"] != null ? Session["mStatus"].ToString() : "");
                var vResultCode = (Session["vResultCode"] != null ? Session["vResultCode"].ToString() : "");
                var mErrMsg = (Session["mErrMsg"] != null ? Session["mErrMsg"].ToString() : "");
                OrderId.Text = orderId;
                PayNowIdStatus.Text = Session["payNowIdStatus"].ToString();
                MStatus.Text = mStatus;
                VResultCode.Text = vResultCode;
                MErrMsg.Text = mErrMsg;
                Session.Remove("payNowIdStatus");
                return;
            }
            
            String httpAccept = null;
            String accept = Request.Headers.Get("Accept");
            if (accept != null)
            {
                httpAccept = accept;
            }
            // HTTP-USERAGENTの取得
            String userAgent = HttpContext.Current.Request.UserAgent;


            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            String warning = null;
            if (String.IsNullOrEmpty(orderId))
            {
                warning = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font>";
            }
            else if (String.IsNullOrEmpty(amount))
            {
                warning = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font>";
            }

            // エラー時の処理
            if (String.IsNullOrEmpty(warning) == false)
            {
                Session["warning"] = warning;
                // 入力画面に戻る
                Response.Redirect("./MpiAuthorize.aspx", true);
                return;
            }


            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var reqDto = new MpiAuthorizeRequestDto
                {
                    OrderId = orderId, // オーダーIDの設定
                    Amount = amount, // 金額の設定
                    HttpAccept = httpAccept, // Acceptの設定
                    HttpUserAgent = userAgent, // UserAgentの設定
                    RedirectionUri = termUrl, // RedirectionURLの設定
                    AccountId = accountId //会員ID
                };
            if (!String.IsNullOrEmpty(cardId)) reqDto.CardId = cardId;
            if (!String.IsNullOrEmpty(cardNumber)) reqDto.CardNumber = cardNumber;
            if (!String.IsNullOrEmpty(cardExpire)) reqDto.CardExpire = cardExpire;

            // 決済種別
            // サービスオプションタイプの設定（固定値）
            switch (paymentMode)
            {
                case "1":
                    reqDto.ServiceOptionType = "mpi-none";
                    break;
                case "2":
                    reqDto.ServiceOptionType = "mpi-complete";
                    break;
                case "3":
                    reqDto.ServiceOptionType = "mpi-company";
                    break;
                case "4":
                    reqDto.ServiceOptionType = "mpi-merchant";
                    break;
            }


            // ペイメントオプション(支払方法・回数)の設定
            String jpo = null;
            if ("10" == jpo1 || "80" == jpo1)
            {
                jpo = jpo1;
            }
            else if ("61" == jpo1 && jpo2 != null)
            {
                jpo = jpo1 + "C" + jpo2;
            }
            if (jpo != null) reqDto.Jpo = jpo;
            // セキュリティコード設定
            if (!string.IsNullOrEmpty(securityCode)) reqDto.SecurityCode = securityCode;
            // 与信方法によって、売上フラグを設定
            if ("1" == withCapture) reqDto.WithCapture = "true";

            /* ******************************************* */
            /* 標準カードフラグを設定する場合に設定(未設定時は1)   */
            /* ******************************************* */
            //reqDto.DefaultCard("1");

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            var tran = new Transaction();
            var resDto = (MpiAuthorizeResponseDto)tran.Execute(reqDto);


            if (resDto.Mstatus == SampleConstants.TXN_FAILURE_CODE)
            {

                OrderId.Text = resDto.OrderId;
                MStatus.Text = resDto.Mstatus;
                VResultCode.Text = resDto.VResultCode;
                MErrMsg.Text = resDto.MerrMsg;

                if (resDto.PayNowIdResponse != null)
                {
                    PayNowIdStatus.Text = resDto.PayNowIdResponse.Status;
                }
            }
            else
            {
                Response.Write(resDto.ResResponseContents);
            }

        }
    }
}
