﻿using System;
using System.Collections.Generic;
using System.Collections.Specialized;
using System.Text;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using MdkSampleDotNet;

namespace web.push
{
    public partial class PayNowIdRecurringPushReceipt : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            //改ざんチェック用のHMACをリクエストヘッダより取得します。
            String contentHmac = Request.Headers["content-hmac"];
            if (String.IsNullOrEmpty(contentHmac))
            {
                //決済通知受信に失敗
                throw new HttpException(500, "Internal Server Error !!!");
            }
            // --------------------------------------------------------
            // Content-HMAC を利用して電文の改竄チェックを行います。
            // --------------------------------------------------------
            var encoding = Request.ContentEncoding;
            var reader = new System.IO.StreamReader(Request.InputStream, encoding);

            String body = reader.ReadToEnd();
            Console.WriteLine(Request.InputStream);

            //マーチャントユーティリティを利用してメッセージの改ざんをチェックします。
            bool check = jp.veritrans.tercerog.mdk.MerchantUtility.CheckMessage(body, contentHmac);
            if (check == false)
            {
                //決済通知受信に失敗→改ざんされている
                throw new HttpException(400, "Data does not belongs to me ..");

            }

            //Requsetヘッダの表示
            DispRequestInfo();

            //サンプルではPUSHされた電文の内容をCSVとして出力します。
            txtHttpForm.Text = OutputTrans(body);

            // 入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答します。
        }


        public void DispRequestInfo()
        {
            NameValueCollection collection = Request.Headers;

            txtHttpHeaders.Text = "";
            foreach (string key in collection.AllKeys)
            {

                txtHttpHeaders.Text += key + ":" + collection[key] + "\n";
            }

        }
        /// <summary>
        /// PUSHされた電文の内容をCSVとして出力します。
        /// </summary>
        public String OutputTrans(String requestBody)
        {
            var fileWriteString = new StringBuilder();

            fileWriteString.Append("---------------------------------------------------\n");
            fileWriteString.Append("pushTime:" + Request.Form["pushTime"] + "\n");
            fileWriteString.Append("pushId:" + Request.Form["pushId"] + "\n");
            fileWriteString.Append("numberOfNotify:" + Request.Form["numberOfNotify"] + "\n");
            fileWriteString.Append("---------------------------------------------------\n");

            //取引の件数を取得します。
            int tranCount = Convert.ToInt32(Request.Form["numberOfNotify"]);

            for (int i = 0; i < tranCount; i++)
            {
                String count = String.Format("{0:d4}", i);
                fileWriteString.Append(Request.Form[("accountId" + count)] + ",");       // 会員ID
                fileWriteString.Append(Request.Form[("orderId" + count)] + ",");       // 会員ID
                fileWriteString.Append(Request.Form[("txnType" + count)] + ",");         // トランザクションタイプ
                fileWriteString.Append(Request.Form[("mstatus" + count)] + ",");     // 処理ステータス
                fileWriteString.Append(Request.Form[("txnTime" + count)] + ",");     // 処理日時
                fileWriteString.Append(Request.Form[("chargeGroupId" + count)] + ",");     // 課金グループID
                fileWriteString.Append(Request.Form[("chargeAmount" + count)] + ",");     // 課金金額
                fileWriteString.Append(Request.Form[("chargeDate" + count)] + ",");     // 課金実施年月日
                fileWriteString.Append(Request.Form[("dummy" + count)] + ",");           // ダミー決済フラグ
                fileWriteString.Append("\n");
            }

            //ファイル出力
            var sw = new System.IO.StreamWriter(
                Utils.getXPath(SampleConstants.PUSH_OUTPUT_DIRECTORY)
                + @"\PayNowIdPushReceipt.csv", true, Encoding.GetEncoding("UTF-8"));
            sw.Write(fileWriteString.ToString());
            sw.Close();

            return fileWriteString.ToString();


        }
    }
}
