﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;
using System.Collections.Specialized;
using System.IO;
using System.Text;

namespace MdkSampleDotNet.push
{
    public partial class PaypalPushReceipt : System.Web.UI.Page
    {
        protected void Page_Load(object sender, EventArgs e)
        {
            //改ざんチェック用のHMACをリクエストヘッダより取得します。
            String contentHmac = Request.Headers["content-hmac"];
            //contentHmac = "h=HmacSHA256;s=sample1cc;v=145551f5105775d9a6df38212d97258c328fab07045f7cacedad2933bb03d47f";
            if(String.IsNullOrEmpty(contentHmac)){
                //決済通知受信に失敗
                throw new HttpException(500, "Internal Server Error !!!");
            }

            // --------------------------------------------------------
            // Content-HMAC を利用して電文の改竄チェックを行います。
            // --------------------------------------------------------
            System.Text.Encoding encoding = Request.ContentEncoding;
            System.IO.StreamReader reader = new System.IO.StreamReader(Request.InputStream, encoding);

            String body = reader.ReadToEnd();
            Console.WriteLine(Request.InputStream);

            //マーチャントユーティリティを利用してメッセージの改ざんをチェックします。
            bool check = jp.veritrans.tercerog.mdk.MerchantUtility.CheckMessage(body, contentHmac);
            if (check == false)
            {
                //決済通知受信に失敗→改ざんされている
                throw new HttpException(500, "Internal Server Error !!!");

            }

            //Requsetヘッダの表示
            DispRequestInfo();

            //サンプルではPUSHされた電文の内容をCSVとして出力します。
            txtHttpForm.Text = OutputTrans(body);

            // 入金通知処理終了。ベリトランスペイメントゲートウェイへ 200 OK を応答します。

        }


        public void DispRequestInfo()
        {
            NameValueCollection collection = Request.Headers;

            txtHttpHeaders.Text = "";
            foreach (string key in collection.AllKeys)
            {

                txtHttpHeaders.Text += key + ":" + collection[key] + "\n";
            }

        }
        /// <summary>
        /// PUSHされた電文の内容をCSVとして出力します。
        /// </summary>
        public String OutputTrans(String requestBody)
        {
            StringBuilder fileWriteString = new StringBuilder();

            fileWriteString.Append("---------------------------------------------------\n");
            fileWriteString.Append("pushTime:" + Request.Form["pushTime"] + "\n");
            fileWriteString.Append("pushId:" + Request.Form["pushId"] + "\n");
            //速報："0"、確報："1"
            fileWriteString.Append("fixed:" + Request.Form["fixed"] + "\n");
            fileWriteString.Append("numberOfNotify:" + Request.Form["numberOfNotify"] + "\n");
            fileWriteString.Append("---------------------------------------------------\n");

            //取引の件数を取得します。
            int tranCount = Convert.ToInt32(Request.Form["numberOfNotify"]);

            for (int i = 0; i < tranCount; i++)
            {
                String count = String.Format("{0:d4}", i);

                fileWriteString.Append(Request.Form[("orderId" + count)] + ",");         　//取引ID
                fileWriteString.Append(Request.Form[("txnType" + count)] + ",");　         //トランザクションタイプ
                fileWriteString.Append(Request.Form[("receivedDatetime" + count)] + ",");　// 受付日時
                fileWriteString.Append(Request.Form[("amount" + count)] + ",");　          // 金額
                fileWriteString.Append(Request.Form[("payerId" + count)] + ",");　         // お客様番号
                fileWriteString.Append(Request.Form[("centerTxnId" + count)] + ",");　     // 取引識別子
                fileWriteString.Append(Request.Form[("dummy" + count)] + ",");　           //ダミー決済フラグ


                fileWriteString.Append("\n");

            }

            //ファイル出力
            System.IO.StreamWriter sw = new System.IO.StreamWriter(Utils.getXPath(SampleConstants.PUSH_OUTPUT_DIRECTORY) + @"\PaypalPushReceipt.csv", true, System.Text.Encoding.GetEncoding("UTF-8"));
            sw.Write(fileWriteString.ToString());
            sw.Close();

            return fileWriteString.ToString();


        }


    }
}
