﻿using System;
using System.Collections;
using System.Configuration;
using System.Data;
using System.Web;
using System.Web.Security;
using System.Web.UI;
using System.Web.UI.HtmlControls;
using System.Web.UI.WebControls;
using System.Web.UI.WebControls.WebParts;
using jp.veritrans.tercerog.mdk.dto;
using jp.veritrans.tercerog.mdk;

namespace MdkSampleDotNet.saison
{
    public partial class Authorize : System.Web.UI.Page
    {
        /// <summary>
        /// 初期表示イベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void Page_Load(object sender, EventArgs e)
        {
            if (!Page.IsPostBack)
            {
                dispOrderId.Text = "dummy" + Utils.CurrentTimeMillis();
                orderId.Value = "dummy" + Utils.CurrentTimeMillis();
                amount.Text = Request.QueryString["price"];
            }
        }

        /// <summary>
        /// 取引ID更新ボタンイベント。
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnReplaceOrderId_Click(object sender, EventArgs e)
        {
            dispOrderId.Text = "dummy" + Utils.CurrentTimeMillis();
            orderId.Value = "dummy" + Utils.CurrentTimeMillis();
        }

        /// <summary>
        /// 購入ボタンイベント
        /// </summary>
        /// <param name="sender"></param>
        /// <param name="e"></param>
        protected void btnSubmit_Click(object sender, EventArgs e)
        {
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 取引ID
            String paramOrderId = orderId.Value;
            // 支払金額
            String paramAmount = amount.Text;

            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // ++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++++
            if (String.IsNullOrEmpty(paramOrderId))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：取引IDが指定されていません</b></font><br/><br/>";
                return;
            }
            if (String.IsNullOrEmpty(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>必須項目：金額が指定されていません</b></font><br/><br/>";
                return;
            }
            if (!IsNumber(paramAmount))
            {
                errorMessage.Text = "<font color='#ff0000'><b>金額は数値で入力しなければなりません</b></font><br/><br/>";
                return;
            }

            Session["amount"] = paramAmount;

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            SaisonAuthorizeRequestDto requestData = new SaisonAuthorizeRequestDto();
            requestData.OrderId = paramOrderId;
            requestData.SettlementMethod = Utils.getXPath(SampleConstants.SAISON_PC_OR_SP_SETTLEMENT_METHOD);
            requestData.MerchantRedirectionUri = Utils.getXPath(SampleConstants.SAISON_MERCHANT_REDIRECTION_URI_PC);

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // コマンドを実行し、応答DTOを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            Transaction tran = new Transaction();
            SaisonAuthorizeResponseDto responseData = (SaisonAuthorizeResponseDto)tran.Execute(requestData);


            if (SampleConstants.TXN_SUCCESS_CODE == responseData.Mstatus)
            {
                Response.Redirect(responseData.ResResponseContents);
            }
            else {
                Session["_screen"] = _screen.Value;
                Session["processName"] = "与信";
                Session["orderId"] = responseData.OrderId;
                Session["mStatus"] = responseData.Mstatus;
                Session["mErrMsg"] = responseData.MerrMsg;
                Session["vResultCode"] = responseData.VResultCode;

                Response.Redirect("./Result.aspx", true);
            }
        }
        /// <summary>
        /// 引数が数値であるかを確認。
        /// </summary>
        /// <param name="strNum">確認する文字列</param>
        /// <returns>数値の場合はtrueを返す</returns>
        private bool IsNumber(string strNum)
        {
            double dNullable;

            return double.TryParse(
                strNum,
                System.Globalization.NumberStyles.Any,
                null,
                out dNullable
            );
        }
    }
}
