﻿using System;
using System.Collections.Generic;
using System.Web;
using System.Web.UI;
using System.Web.UI.WebControls;
using jp.veritrans.tercerog.mdk;
using jp.veritrans.tercerog.mdk.dto;

namespace web.search.upop
{
    public partial class SearchExec : System.Web.UI.Page
    {
        protected OrderInfo order_info;
        protected void Page_Load(object sender, EventArgs e)
        {
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // パラメータを取得します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            String orderId = Request["orderId"];               // 取引ID

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 入力をチェックします。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++

            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // 要求DTOを生成し、値を設定します。
            // +++++++++++++++++++++++++++++++++++++++++++++++++++++
            // Commonパラメータクラスへのセット
            CommonSearchParameter common_param = new CommonSearchParameter();
            common_param.OrderId = orderId;

            // Searchパラメータクラスへのセット
            SearchParameters serach_param = new SearchParameters();
            serach_param.Common = common_param;

            // 検索DTOへパラメータクラスをセット
            SearchRequestDto request_data = new SearchRequestDto();
            request_data.NewerFlag = "false"; // 商品に紐付く全ての取引のみ対象にするかを示す
            request_data.ContainDummyFlag = "1";          // 検索対象にダミー決済のレコードを含めるかを示す
            request_data.ServiceTypeCd = new String[] { "upop" };   // 検索対象のサービスタイプを示す
            request_data.SearchParameters = serach_param; // 各機能の固有条件

            try
            {
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // コマンドを実行し、応答DTOを取得します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                var tran = new Transaction();
                var response_data = (SearchResponseDto)tran.Execute(request_data);

                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 結果画面に表示します。
                // +++++++++++++++++++++++++++++++++++++++++++++++++++++
                // 処理結果メッセージを設定（View機能へ引き渡す）
                String warning = response_data.MerrMsg;
                if (warning != null && 0 < warning.Length)
                {
                    errorMessage.Text = "<font color='#ff0000' size='2'><b>" + warning + "</b></font><br/><br/>";
                }

                // 配列データを設定（View機能へ引き渡す）
                OrderInfos order_infos = response_data.OrderInfos;
                if (order_infos != null && order_infos.OrderInfo != null && order_infos.OrderInfo.Length > 0)
                {
                    order_info = order_infos.OrderInfo[0];
                }

            }
            catch (Exception ex)
            {
                // トランザクションオブジェクトの生成失敗など、
                // Exceptionが発生した場合はエラー画面を表示します。
                errorMessage.Text = "<font color='#ff0000' size='2'><b>Exception Occured : " + ex.Message + "</b></font><br/><br/>";
                return;
            }
        }

        /// <summary>
        /// フォームから送られてきた配列パラメータを取得する。
        /// </summary>
        /// <param name="key">パラメータ名</param>
        /// <param name="rtnNull">戻り値が配列0の場合の挙動（falseの場合は配列0で、trueの場合はnullで変える）</param>
        /// <returns>パラメータ名に紐付く値の配列（無い場合は配列数0個の文字列配列を返す）</returns>
        private String[] getListParam(String key)
        {
            String tmpListString = (String)Session[key];

            if (tmpListString == null || tmpListString.Length == 0)
            {
                return null;
            }

            char[] delimiter = new char[] { ',' };
            return tmpListString.Split(delimiter);
        }

        private String getSessionParam(String key)
        {
            String param = (String)Session[key];

            if (param == null || param.Length == 0)
            {
                return null;
            }

            return param;
        }
        /// <summary>
        /// 検索対象の決済サービスタイプであるかをチェックする。
        /// </summary>
        /// <param name="serviceTypeCd">選択されたサービスタイプのリスト</param>
        /// <param name="target">探し出すサービスタイプ</param>
        /// <returns>存在する場合はtrueを返す</returns>
        private bool CheckService(String[] serviceTypeCd, String target)
        {
            if (serviceTypeCd == null)
            {
                return false;
            }
            return -1 < Array.IndexOf(serviceTypeCd, target);
        }
    }
}